# Gimulator Client for Python
A client for [Gimulator project](https://github.com/Gimulator/Gimulator) written in Python.

# Installation
## Stable release
You can install the stable release of the package via:
```
pip install gimulator-py
```
## Latest release
Installing and using the latest release is **not recommended** since the project is still under heavy development. But if you are really keen to try the latest releases, run the following command:
```
pip install git+https://github.com/Gimulator/client-python.git
```

# Usage
